import re

from pygments.lexer import bygroups, include
from pygments.lexers.javascript import JavascriptLexer
from pygments.token import Name, Operator, Punctuation, String, Text


# Use same tokens as `JavascriptLexer`, but with tags and attributes support
TOKENS = JavascriptLexer.tokens
TOKENS.update({
    'jsx': [
        (r'(<)(\s*)([\w]+)',
         bygroups(Punctuation, Text, Name.Tag), 'tag'),
        (r'(<)(\s*)(/)(\s*)([\w]+)(\s*)(>)',
         bygroups(Punctuation, Text, Punctuation, Text, Name.Tag, Text,
                  Punctuation)),
    ],
    'tag': [
        (r'\s+', Text),
        (r'([\w]+\s*)(=)(\s*)', bygroups(Name.Attribute, Operator, Text),
         'attr'),
        (r'[\w]+', Name.Attribute),
        (r'(/?)(\s*)(>)', bygroups(Punctuation, Text, Punctuation), '#pop'),
    ],
    'attr': [
        ('\s+', Text),
        ('".*?"', String, '#pop'),
        ("'.*?'", String, '#pop'),
        (r'[^\s>]+', String, '#pop'),
    ],
})
TOKENS['root'].insert(0, include('jsx'))


class JsxLexer(JavascriptLexer):
    name = 'react'
    aliases = ['jsx', 'react']
    filenames = ['*.jsx', '*.react']
    mimetypes = ['text/jsx', 'text/typescript-jsx']

    flags = re.MULTILINE | re.DOTALL | re.UNICODE

    tokens = TOKENS



import io
import os

from setuptools import setup, find_packages


VERSION = '0.0.2'
here = os.path.abspath(os.path.dirname(__file__))
README = io.open(os.path.join(here, 'README.rst'), encoding="utf8").read()

setup(
    name='jsx-lexer',
    description='A JSX lexer for Pygments',
    long_description=README,
    version=VERSION,
    url='https://github.com/fcurella/jsx-lexer',
    author='Flavio Curella',
    author_email='flavio.curella@gmail.com',
    classifiers=[
        'Environment :: Plugins',
        'Intended Audience :: Developers',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3'
    ],
    keywords='pygments highlight jsx react',
    install_requires=[
        'Pygments >= 2.1'
    ],
    test_suite='tests',
    license='MIT License',
    packages=find_packages(exclude=["docs", "tests", "tests.*"]),
    entry_points="""
        [pygments.lexers]
        jsx=jsx:JsxLexer
    """
)
